Transition

Struct Transition 

pub struct Transition<'a, Message, Theme, Renderer, P>
where P: Program,
{ /* private fields */ }
A widget that can be used to animate its contents.

Implementations

Source

impl<'a, Message, Theme, Renderer, P> Transition<'a, Message, Theme, Renderer, P>
where Renderer: Renderer, P: Program,

pub fn new<E>( init: impl Fn() -> P + 'a, value: P::Value, view: impl Fn(&P, Instant) -> E + 'a, ) -> Self
where E: Into<Element<'a, Message, Theme, Renderer>>,

Creates a new Transition.

The init closure will be used to initialize an animation.

The view closure will receive the animation and an Instant, which can be used for interpolating values. This will be called every frame until the given value is reached.

pub fn id(self, id: impl Into<Id>) -> Self

Sets the widget::Id of the Transition.

The widget::Id can subsequently be used to reset the [Animation] via reset.

pub fn key(self, key: impl Hash) -> Self

Sets the key of the Transition widget for continuity.

Changing the key will reset the [Animation].

pub fn on_finish(self, on_finish: Message) -> Self
where Message: Clone + 'a,

Sets the message that will be produced when the Transition has finished animating.

Note that if an [Animation] is set to loop forever, the message will never be produced!

pub fn on_finish_maybe(self, on_finish: impl Into<Option<Message>>) -> Self
where Message: Clone + 'a,

Sets the message that will be produced when the Transition has finished animating, if Some.

Note that if an [Animation] is set to loop forever, the message will never be produced!

pub fn on_finish_with(self, on_finish: impl Fn() -> Message + 'a) -> Self

Sets the message that will be produced when the Transition has finished animating.

This is analogous to Transition::on_finish, but using a closure to produce the message.

This closure will only be called when the Transition has actually finished animating and, therefore, this method is useful to reduce overhead if creating the resulting message is slow.

Note that if an [Animation] is set to loop forever, the message will never be produced!