pub trait Program: 'static {
type Value: Copy + 'static;
// Required methods
fn go(&mut self, value: Self::Value, now: Instant);
fn is_animating(&self, now: Instant) -> bool;
}Expand description
The logic of a Transition.
Required Associated Types
Required Methods
Sourcefn go(&mut self, value: Self::Value, now: Instant)
fn go(&mut self, value: Self::Value, now: Instant)
Transitions the Program from its current state towards the given value at
the given time.
Sourcefn is_animating(&self, now: Instant) -> bool
fn is_animating(&self, now: Instant) -> bool
Returns true if the Program is currently in progress.